@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.602';
+our $VERSION = '1.603';
 
 use Exporter qw( import );
 
@@ -37,10 +37,11 @@ our %EXPORT_TAGS = (
         KEY_ENTER KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_q KEY_Tilde KEY_BSPACE
         VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN
     ) ],
+    screen => [ qw(
+        CLEAR_SCREEN CLEAR_TO_END_OF_SCREEN RESET REVERSE BOLD_UNDERLINE HIDE_CURSOR SHOW_CURSOR
+    ) ],
     linux  => [ qw(
-        CLEAR_SCREEN CLEAR_TO_END_OF_SCREEN RESET REVERSE BOLD_UNDERLINE
-        HIDE_CURSOR SHOW_CURSOR WIDTH_CURSOR
-        GET_CURSOR_POSITION
+        GET_CURSOR_POSITION WIDTH_CURSOR
         SET_ANY_EVENT_MOUSE_1003 SET_EXT_MODE_MOUSE_1005 SET_SGR_EXT_MODE_MOUSE_1006
         UNSET_ANY_EVENT_MOUSE_1003 UNSET_EXT_MODE_MOUSE_1005 UNSET_SGR_EXT_MODE_MOUSE_1006
         NEXT_get_key
